@@ -51,4 +51,4 @@ class Registry(object):
 zvt_context = Registry()
 
 # the __all__ is generated
-__all__ = ["zvt_context"]
+__all__ = ["Registry", "zvt_context"]
