@@ -6,12 +6,24 @@ __all__ = []
 # common code of the package
 # export interface in __all__ which contains __all__ of its sub modules
 
+# import all from submodule em_index_meta_recorder
+from .em_index_meta_recorder import *
+from .em_index_meta_recorder import __all__ as _em_index_meta_recorder_all
+
+__all__ += _em_index_meta_recorder_all
+
 # import all from submodule em_stockus_meta_recorder
 from .em_stockus_meta_recorder import *
 from .em_stockus_meta_recorder import __all__ as _em_stockus_meta_recorder_all
 
 __all__ += _em_stockus_meta_recorder_all
 
+# import all from submodule em_currency_meta_recorder
+from .em_currency_meta_recorder import *
+from .em_currency_meta_recorder import __all__ as _em_currency_meta_recorder_all
+
+__all__ += _em_currency_meta_recorder_all
+
 # import all from submodule em_stockhk_meta_recorder
 from .em_stockhk_meta_recorder import *
 from .em_stockhk_meta_recorder import __all__ as _em_stockhk_meta_recorder_all
